summaryrefslogtreecommitdiff
path: root/ide-usages.c
diff options
context:
space:
mode:
Diffstat (limited to 'ide-usages.c')
-rw-r--r--ide-usages.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/ide-usages.c b/ide-usages.c
index 4caa644..9ae31e4 100644
--- a/ide-usages.c
+++ b/ide-usages.c
@@ -124,10 +124,10 @@ void usages_process_lsp_response(Ted *ted, const LSPResponse *response) {
fclose(last_file);
buffer_set_view_only(buffer, true);
// the build_dir doesn't really matter since we're using absolute paths
// but might as well set it to something reasonable.
char *root = ted_get_root_dir(ted);
- strbuf_cpy(ted->build_dir, root);
+ build_set_working_directory(ted, root);
free(root);
build_check_for_errors(ted);
@@ -124,10 +124,10 @@ void usages_process_lsp_response(Ted *ted, const LSPResponse *response) {
fclose(last_file);
buffer_set_view_only(buffer, true);
- // the build_dir doesn't really matter since we're using absolute paths
+ // the build directory doesn't really matter since we're using absolute paths
// but might as well set it to something reasonable.
char *root = ted_get_root_dir(ted);